@@ -139,6 +139,12 @@ class Actor:
                     else:
                         logger.error("Task was never assigned to this actor")
                         if self.strict: raise Exception("Received cancellation for Task that was never assinged to this actor!")
+                        await self.transport.forward(AssignCancelledMessage(data={
+                            "canceller": str("Cancelled because actor receiving this cancellation never had this task but was also not strict")
+                        }, meta = {
+                            "reference": message.data.assignation,
+                            "extensions": message.meta.extensions
+                        }))
 
 
 
@@ -147,7 +153,7 @@ class Actor:
             await self.log(f"Provision Exception {str(e)}")
             await self.transport.forward(ProvideTransitionMessage(
                 data= {
-                    "state": ProvideState.ERROR,
+                    "state": ProvideState.CRITICAL,
                     "message": f"{e}"
                 },
                 meta={
