@@ -6,6 +6,11 @@ from fakts.grants.beacon import BeaconGrant
 from fakts.grants.endpoint_grant import EndpointGrant
 from fakts.grants.yaml import YamlGrant
 from rich.console import Console
+#importing the os module
+import os
+
+#to get the current working directory
+directory = os.getcwd()
 
 
 class ArkitektOptions(str, Enum):
@@ -13,6 +18,23 @@ class ArkitektOptions(str, Enum):
     DEV = "dev"
 
 
+init_script = f"""
+from arkitekt.agents.script import ScriptAgent
+
+agent = ScriptAgent()
+
+@agent.register()
+def test_show(name: str)-> str:
+    raise NotImplementedError("DD")
+
+agent.provide()
+
+"""
+
+
+
+
+
 
 def main(script = ArkitektOptions.INIT, name=None, refresh=False):
     
@@ -30,6 +52,15 @@ def main(script = ArkitektOptions.INIT, name=None, refresh=False):
                 fakts.load()
 
 
+        with open(os.path.join(directory, "run.py")) as f:
+            f.write(init_script)
+
+
+
+
+
+
+
 
 
     print(name)
